.. include:: ../BADGES.rst
To Do
=====
Eventually these items will make there way to the issues section of http://bitbucket.org/timcera/astronomia::

    Improve the lunar model, perhaps with the complete
    Chapront ELP2000-82.

    Add more material from Meeus:

      Add a model for Pluto.

      Add year-by-year polynomial model for planets Jupiter
      through Neptune.

      Add perihelion/aphelion routines for the planets, and
      perigee/apogee routines for the Moon.

      Look at adjustable truncation of the VSOP model to
      trade accuracy for time.

    Fix a bug in the Rise-Set-Transit code which causes events
    around 0hr UT to be dropped.

    Fix a bug in cronus.py that causes equinox/solstice events
    to be reported out of order on that day. (The displayed
    values are correct, though).

    Improve the param file parsing so people can enter their
    longitude and latitude more naturally.
